package cz.frantovo.nekurak.dao;

import cz.frantovo.nekurak.dto.Podnik;
import java.util.Collection;
import org.springframework.jdbc.core.JdbcTemplate;

/**
 * Stará se o načítání a ukládání podniků (hospod) z a do databáze.
 * @author fiki
 */
public class PodnikDAO extends NekurakSuperDAO {

    private enum SQL {

	SELECT_VSECHNY,
	INSERT,
	UPDATE,
	NEXTVAL
    }
    private PodnikRowMapper podnikRowMapper = new PodnikRowMapper();
    private JdbcTemplate jdbcTemplate = new JdbcTemplate(getSpojeni());

    public Collection<Podnik> getPodniky() {
	return jdbcTemplate.query(getSQL(SQL.SELECT_VSECHNY), podnikRowMapper);
    }

    /**
     * Uloží podnik do databáze.
     * @param p Podnik k uložení. Pokud má být vložen nový, má id = 0.
     * @return id vloženého nebo uloženého podniku.
     */
    public int ulozPodnik(Podnik p) {
	if (p.getId() == 0) {
	    p.setId(jdbcTemplate.queryForInt(getSQL(SQL.NEXTVAL)));
	    jdbcTemplate.update(getSQL(SQL.INSERT), new Object[]{p.getNazev(), p.getId()});
	} else {
	    jdbcTemplate.update(getSQL(SQL.UPDATE), new Object[]{p.getNazev(), p.getId()});
	}
	return p.getId();
    }
}
